pub struct TypedArray<T, S>where
T: TypedArrayElement,
S: JSObjectStorage,{
object: S,
computed: Cell<ArrayData<<T as TypedArrayElement>::Element>>,
}Expand description
A typed array wrapper.
Fields
object: Scomputed: Cell<ArrayData<<T as TypedArrayElement>::Element>>Implementations
Sourceimpl<T, S> TypedArray<T, S>where
T: TypedArrayElement,
S: JSObjectStorage,
impl<T, S> TypedArray<T, S>where
T: TypedArrayElement,
S: JSObjectStorage,
Sourcepub fn from(object: *mut JSObject) -> Result<TypedArray<T, S>, ()>
pub fn from(object: *mut JSObject) -> Result<TypedArray<T, S>, ()>
Create a typed array representation that wraps an existing JS reflector. This operation will fail if attempted on a JS object that does not match the expected typed array details.
Sourcepub unsafe fn underlying_object(&self) -> &S
pub unsafe fn underlying_object(&self) -> &S
Unsafety
Returned wrapped pointer to the underlying JSObject is meant to be
read-only, modifying it can lead to Undefined Behaviour and violation
of TypedArray API guarantees.
Practically, this exists only to implement JSTraceable trait in Servo
for Box<Heap<*mut JSObject>> variant.
Sourcepub fn to_vec(&self) -> Option<Vec<<T as TypedArrayElement>::Element>>
pub fn to_vec(&self) -> Option<Vec<<T as TypedArrayElement>::Element>>
Retrieves an owned data that’s represented by the typed array. Returns None if the underlying buffer is detached.
Sourcepub unsafe fn as_slice(&self) -> Option<&[<T as TypedArrayElement>::Element]>
👎Deprecated: use as_slice_safe instead
pub unsafe fn as_slice(&self) -> Option<&[<T as TypedArrayElement>::Element]>
Sourcepub fn as_slice_safe<'a>(
&self,
_no_gc: &'a NoGC,
) -> Option<&'a [<T as TypedArrayElement>::Element]>
pub fn as_slice_safe<'a>( &self, _no_gc: &'a NoGC, ) -> Option<&'a [<T as TypedArrayElement>::Element]>
Returns None if the underlying array buffer is detached. Otherwise, returns Some with the slice data.
Sourcepub unsafe fn as_mut_slice(
&mut self,
) -> Option<&mut [<T as TypedArrayElement>::Element]>
👎Deprecated: use as_mut_slice_safe instead
pub unsafe fn as_mut_slice( &mut self, ) -> Option<&mut [<T as TypedArrayElement>::Element]>
pub fn as_mut_slice_safe<'a>( &mut self, _no_gc: &'a NoGC, ) -> Option<&'a mut [<T as TypedArrayElement>::Element]>
Return a boolean flag which denotes whether the underlying buffer is a SharedArrayBuffer.
Sourceimpl<T, S> TypedArray<T, S>
impl<T, S> TypedArray<T, S>
Sourcepub unsafe fn create(
cx: *mut JSContext,
with: CreateWith<'_, <T as TypedArrayElement>::Element>,
result: MutableHandle<'_, *mut JSObject>,
) -> Result<(), ()>
pub unsafe fn create( cx: *mut JSContext, with: CreateWith<'_, <T as TypedArrayElement>::Element>, result: MutableHandle<'_, *mut JSObject>, ) -> Result<(), ()>
Create a new JS typed array, optionally providing initial data that will be copied into the newly-allocated buffer. Returns the new JS reflector.
Sourcepub fn update(&mut self, data: &[<T as TypedArrayElement>::Element])
pub fn update(&mut self, data: &[<T as TypedArrayElement>::Element])
Update an existed JS typed array
Sourceimpl<S> TypedArray<ArrayBufferViewU8, S>where
S: JSObjectStorage,
impl<S> TypedArray<ArrayBufferViewU8, S>where
S: JSObjectStorage,
pub fn get_array_type(&self) -> Type